using System;
using System.Collections.Generic;
using System.Text;
using System.Data.OleDb;
using System.IO;

using System.Windows.Forms;
/* L F S U I T E     2 0 1 1
 * www.tolaemon.com/lfusite
 * tolaemon 1/10/2011
 * 
 * La utilizacin del codigo de este programa implica la aceptacin de los siguientes puntos:
 * 
 * -Licencia: LFSuite se distribuye bajo licencia "Creative Commons by-nc-sa 3.0", lo que significa que eres libre de compartir ( copiar, distribuir y transmitir ) 
 * y modificar ( readaptar el trabajo ) bajo las siguientes condiciones:
 * -Reconocimiento (Attribution): En cualquier explotacin de la obra autorizada por la licencia har falta reconocer la autora.
 * -No Comercial (Non commercial): La explotacin de la obra queda limitada a usos no comerciales.
 * -Compartir Igual (Share alike): La explotacin autorizada incluye la creacin de obras derivadas siempre que mantengan la misma licencia al ser divulgadas.
 *
 * -Garanta: el autor proporciona este software "tal cual es", sin garantas de ningn tipo. El usuario es el nico responsable de determinar lo apropiado de 
 * utilizar, y modificar este trabajo asumiendo y valorando, a su vez, los riesgos inherentes a ello. Bajo ningn concepto el autor ser responsable de posibles 
 * prdidas, daos, tanto directos como indirectos, especiales o accidentales resultantes de su utilizacin an y cuando este haya sido avisado de la posibilidad
 * de tales daos. 
*/
namespace LFSuite
{
   
    static class Analizador
    {
        public static string nombre_BBDD ;
        public enum tipo_division { Primera = 1, Segunda = 2, PrimeraSegunda = 3 };
        // constantes con la puntuacion de cada resultado
        public const int PUNTOS_VICTORIA = 3;
        public const int PUNTOS_EMPATE = 1;
        public const int PUNTOS_DERROTA = 0;

        static OleDbConnection conector_BBDD ;
      

        /*Description:
         *  Conecta con la base de datos que se recibe por parmtros
         *Recives:
         *   _nombre_BBDD con el nombre del fichero de la BBDD
         * Returns:
         *      true: si ha podido conectar
         *      false: si no ha podido conectar
         */
        public static bool Conectar(string _nombre_BBDD)
        {
            
            try{
                // guardamos el nombre del fichero para tenerlo ...
                nombre_BBDD = _nombre_BBDD;
                
                // se conecta a la base de datos
                conector_BBDD = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source=" + nombre_BBDD + ";");
                conector_BBDD.Open();

                // parece que todo ha ido bien
                return true;
                
            }catch(System.Exception){

                conector_BBDD = null;

                // algo ha fallado
                return false;

            }//try
        
        }//Conectar



        /*Description:
         *  Desconecta de la base de datos
         *Recives:
         *Returns:
         *     true: si ha podido desconectar
         *     false: si no ha podido desconectar
         */
        public static bool Desconectar()
        {
            try{
                // se desconecta a la base de datos
                conector_BBDD.Close();
                
                conector_BBDD.Dispose();

                // parece que todo ha ido bien
                return true;

            }catch(System.Exception){

                // parece que algo ha fallado
                return false;          
            
            }//try
        
        }//Desonectar


        /*Description:
        *  Funcion que permite saber si el analizador esta creado y conectado a la base de datos o no
        * Recives:
        * Returns:
        * Por valor:
        *      true: si esta conectado
        *      false: si NO esta conectado
        */
        public static bool EstaConectado(){

            if (conector_BBDD != null){
                return true;            
            }else{
                return false;            
            }//if
        
        }//EstaConectado



        /*Description:
         * Funcion que permite conocer el total de equipos que hay en la BBDD
         *Recives:
         * Returns:
         * Por valor:
         *      entero con el total de equipos diferentes que hay en la lista de equipos de la BBDD
         */
        public static int ConsultaTotalEquipos()
        {
             OleDbCommand comando_sql;
             OleDbDataReader lector_consulta;
             string cadena_comando_sql;
             int resultado; 

             //Se revisa si la temporada (anio1_temporada,anio2_temporada) recibida se encuentra en la tabla de Temporadas
             //'de la base de datos o si en cambio hay que insertarla
             // SELECT COUNT(expression) FROM tables WHERE predicates;
            
            cadena_comando_sql = "SELECT COUNT(Equipo) FROM Equipos";
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            lector_consulta.Read();
            
            resultado = lector_consulta.GetInt32(0);

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaTotalEquipos  


        /*Description:
        *   Funcion que retorna una lista con todos los equipos almacenados en la BBDD
        * Recives:
        * Returns:
        *   Retorna por referencia la lista de equipos presentes en la base de datos
        * Por valor:
        *   entero con el total de equipos diferentes que hay en la lista 
        */
        public static int ConsultaEquipos(List<int> Lista_Equipos_Id, List<string> Lista_Equipos_Equipo)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql;
            int resultado;

            // selecciona todos los equipos
            cadena_comando_sql = "SELECT Id, Equipo FROM Equipos";
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // va leiendo 
            resultado = 0;            
            while (lector_consulta.Read()){
                Lista_Equipos_Id.Add(lector_consulta.GetInt32(0));
                Lista_Equipos_Equipo.Add(lector_consulta.GetString(1));
                resultado = resultado + 1;
            }//while
  
            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaTotalEquipos  


        /*Description:
        *   Funcion la cual dado un id de una temporada, retorna por referencia 
        * el resto de campos asociados a ella como son el ao1 el ao2 y las anotaciones
        * asociadas. 
        * Recives:        
        *   id : con el identificador de la temporada
        * Returns:
        *   Retorna por referencia 
        *   anio1 : ao inicial del rango
        *   anio2 : ao final del rango
        *   nota : cadena con ls anotiaciones
        * Por valor:
        *   true si ha localizado la temporada con el id indicado
        *   false si no ha localizado la temporada con el id indicado
        */
        public static bool ConsultaTemporada(int id, ref  int anio1, ref int anio2, ref  string nota)
        {
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql = "";
            bool resultado;

            resultado = false;

            cadena_comando_sql = "SELECT T.Anio1 , T.Anio2 , T.Notas FROM Temporadas T  WHERE T.Id = "+id.ToString();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            if (lector_consulta.Read()){
                anio1 = lector_consulta.GetInt32(0);
                anio2 = lector_consulta.GetInt32(1);
                nota = lector_consulta.GetString(2);
                resultado = true;
            }else{
                resultado = false;
            }//if

            return resultado;

        }//ConsultaTemporada

       

        /*Description:
        *   Funcion que retorna una lista con todos las temporadas almacenadas en la BBDD. La peculiaridad es que si especificamos
        * la primera y segunda division nos retrona el rago de temporadas mas pequeo de los 2, es decir nos retrona el rango
        * de temporadas en que hay datos de ambas divisiones
        * Recives:        
        *      division: con la division o divisiones de la que queremos conocer el total de temporadas peresentes en la BBDD
        * Returns:
        *   Retorna por referencia 
        *       la lista de IDs de las temporadas presentes en la base de datos
        *       la lista con los aos de cada temporada
        * Por valor:
        *   entero con el total de temporadas en la lista 
        */
        public static int ConsultaRangoMenorTemporadas(List<int> Lista_Temporadas_Id, List<string> Lista_Temporadas_Anio1_Anio2, tipo_division division)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql="";
            int resultado;

            // selecciona todos las temporadas de la division/es indicada/s
            switch (division){
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 1";
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 2";
                    break;
                case tipo_division.PrimeraSegunda:
                   
                    // APAO ATENCION : apao motivado por las limitaciones de Access SQL
                    // A la hora de obtener el rango de temporadas a analizar debemos quedarnos con el rango de temporadas mas pequeo ya que sino
                    // cuando procesemos las temporadas de las que solo tenemos una division el numero de partidos por jornada cambiar mucho                    
                    // podriamos hacer un INTERSECT de las dos tablas anteriores pero Access no lo permite asi que lo que haremos es hacerlo a mano
                    int id_minimo_1a_div=0;
                    int id_maximo_1a_div = 0;
                    int id_minimo_2a_div = 0;
                    int id_maximo_2a_div = 0;
                    int id_minimo = 0;
                    int id_maximo = 0;

                    // obtenemos ids de la temporada mas antigua y mas nueva de primera division
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 1";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();
                    // leemos el primer y ultimo ID
                    lector_consulta.Read();
                    id_minimo_1a_div = lector_consulta.GetInt32(0);
                    while (lector_consulta.Read()){
                        id_maximo_1a_div = lector_consulta.GetInt32(0);
                    }//while                    
                    lector_consulta.Close();

                    // obtenemos ids de la temporada mas antigua y mas nueva de segunda division
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 2";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();
                    // leemos el primer y ultimo ID
                    lector_consulta.Read();
                    id_minimo_2a_div = lector_consulta.GetInt32(0);
                    while (lector_consulta.Read()){
                        id_maximo_2a_div = lector_consulta.GetInt32(0);
                    }//while                    
                    lector_consulta.Close();

                    // nos quedamos con el id__minimo mayor 
                    if (id_minimo_1a_div > id_minimo_2a_div){
                        id_minimo = id_minimo_1a_div;
                    }else{
                        id_minimo = id_minimo_2a_div;
                    }//if

                    // nos quedamos el id_maximo menor
                    if (id_maximo_1a_div > id_maximo_2a_div){
                        id_maximo = id_maximo_2a_div;
                    }else{
                        id_maximo = id_maximo_1a_div;
                    }//if

                    // ahora si ya podemos crear la consulta de las temporadas adecuadas
                    cadena_comando_sql = "SELECT  Id , Anio1 , Anio2  FROM Temporadas  WHERE  Id>=" + id_minimo.ToString() + " AND Id<=" + id_maximo.ToString();
                    // FIN APAO 

                    break;
                default:
                    break;
            }//switch
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // va leiendo 
            resultado = 0;
            while (lector_consulta.Read())
            {
                Lista_Temporadas_Id.Add(lector_consulta.GetInt32(0));
                Lista_Temporadas_Anio1_Anio2.Add(lector_consulta.GetInt32(1).ToString() + "-" + lector_consulta.GetInt32(2).ToString());
                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaRangoMenorTemporadas  



       /*Description:
       *   Funcion que retorna una lista con todas las temporadas almacenadas en la BBDD.
       * Recives:        
       * Returns:
       *   Retorna por referencia 
       *       la lista de IDs de las temporadas presentes en la base de datos
       *       la lista con los aos de cada temporada
       * Por valor:
       *   entero con el total de temporadas en la lista 
       */
        public static int ConsultaTodasTemporadas(List<int> Lista_Temporadas_Id, List<string> Lista_Temporadas_Anio1_Anio2)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql = "";
            int resultado;

            // seleccionamos todas las temporadas
            cadena_comando_sql = "SELECT * FROM Temporadas";
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // va leiendo 
            resultado = 0;
            while (lector_consulta.Read())
            {
                Lista_Temporadas_Id.Add(lector_consulta.GetInt32(0));
                Lista_Temporadas_Anio1_Anio2.Add(lector_consulta.GetInt32(1).ToString() + "-" + lector_consulta.GetInt32(2).ToString());
                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaTodasTemporadas  


        /*Description:
       *   Funcion que retorna una lista con las temporadas almacenadas en la BBDD cuyos IDs se encuentran entre los IDs que
       * les pasamos por referencia ( ambos incluidos ). Como los IDs estan ordenados cronologicamente obtenedremos todas lar
       * temporadas contenidas dentro del rango de temporadas especificadas. La peculiaridad es que si especificamos
       * la primera y segunda division nos retrona el rago de temporadas mas pequeo de los 2, es decir nos retrona el rango
       * de temporadas en que hay datos de ambas divisiones
       * Recives:        
       *      division: con la division o divisiones de la que queremos conocer el total de temporadas peresentes en la BBDD
       *      id_temporada_orig: con el identificador de la temporada origen ( la mas antigua del rango)
       *      id_temporada_fin: con el identificador de la temporada final ( la mas reciente del rango)
       * Returns:
       *   Retorna por referencia 
       *       la lista de IDs de las temporadas presentes en la base de datos dentro del rango ( con las temporadas limite incluidas )
       *       la lista con los aos de cada temporada presentes dentro del rango ( con las temporadas limite incluidas )
       *   Por valor:
       *       entero con el total de temporadas en la lista 
       */
        public static int ConsultaRangoTemporadas(List<int> Lista_Temporadas_Id, List<string> Lista_Temporadas_Anio1_Anio2, tipo_division division, int id_temporada_orig, int id_temporada_fin)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql = "";
            int resultado;
            int int_aux;

            // si nos han entrado las temporadas al revs ( es decir primero la de fin y luego la de origen ), l
            // las ordenamos. Podemos hacerlo pq los ids de las temporadas estan ordenados cornologicamente en 
            // la BBDD, siendo los IDs mayores los de temporadas mas antiguas y los IDs menores los de temporadas
            // mas recientes
            if (id_temporada_orig < id_temporada_fin)
            {
                int_aux = id_temporada_orig;
                id_temporada_orig = id_temporada_fin;
                id_temporada_fin = int_aux;
            }//if

            // selecciona todos las temporadas de la division/es indicada/s
            switch (division)
            {
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 1 AND T.Id>=" + id_temporada_fin.ToString() + " AND T.Id<=" + id_temporada_orig.ToString();
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 2 AND T.Id>=" + id_temporada_fin.ToString() + " AND T.Id<=" + id_temporada_orig.ToString();
                    break;
                case tipo_division.PrimeraSegunda:

                    // APAO ATENCION : apao motivado por las limitaciones de Access SQL
                    // A la hora de obtener el rango de temporadas a analizar debemos quedarnos con el rango de temporadas mas pequeo ya que sino
                    // cuando procesemos las temporadas de las que solo tenemos una division el numero de partidos por jornada cambiar mucho                    
                    // podriamos hacer un INTERSECT de las dos tablas anteriores pero Access no lo permite asi que lo que haremos es hacerlo a mano
                    int id_minimo_1a_div = 0;
                    int id_maximo_1a_div = 0;
                    int id_minimo_2a_div = 0;
                    int id_maximo_2a_div = 0;
                    int id_minimo = 0;
                    int id_maximo = 0;

                    // obtenemos ids de la temporada mas antigua y mas nueva de primera division
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 1 AND T.Id>=" + id_temporada_fin.ToString() + " AND T.Id<=" + id_temporada_orig.ToString();
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();
                    if (lector_consulta.Read()){
                        // leemos el primer y ultimo ID                        
                        id_minimo_1a_div = lector_consulta.GetInt32(0);
                        id_maximo_1a_div = id_minimo_1a_div;// asignamos un valor inicial por si solo se selecciona una temporada y no entramos en el while
                        while (lector_consulta.Read())
                        {
                            id_maximo_1a_div = lector_consulta.GetInt32(0);
                        }//while
                    }
                    lector_consulta.Close();

                    // obtenemos ids de la temporada mas antigua y mas nueva de segunda division
                    cadena_comando_sql = "SELECT  DISTINCT T.Id , T.Anio1 , T.Anio2  FROM Partidos P , Temporadas T  WHERE  P.Id_Temporada=T.Id AND P.Division = 2 AND T.Id>=" + id_temporada_fin.ToString() + " AND T.Id<=" + id_temporada_orig.ToString();
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();
                    if (lector_consulta.Read()){
                        // leemos el primer y ultimo ID
                        lector_consulta.Read();
                        id_minimo_2a_div = lector_consulta.GetInt32(0);
                        id_maximo_2a_div = id_minimo_2a_div;// asignamos un valor inicial por si solo se selecciona una temporada y no entramos en el while
                        while (lector_consulta.Read())
                        {
                            id_maximo_2a_div = lector_consulta.GetInt32(0);
                        }//while                    
                    }
                    lector_consulta.Close();

                    // nos quedamos con el id__minimo mayor 
                    if (id_minimo_1a_div > id_minimo_2a_div)
                    {
                        id_minimo = id_minimo_1a_div;
                    }
                    else
                    {
                        id_minimo = id_minimo_2a_div;
                    }//if

                    // nos quedamos el id_maximo menor
                    if (id_maximo_1a_div > id_maximo_2a_div)
                    {
                        id_maximo = id_maximo_2a_div;
                    }
                    else
                    {
                        id_maximo = id_maximo_1a_div;
                    }//if

                    // ahora si ya podemos crear la consulta de las temporadas adecuadas
                    cadena_comando_sql = "SELECT  Id , Anio1 , Anio2  FROM Temporadas  WHERE  Id>=" + id_minimo.ToString() + " AND Id<=" + id_maximo.ToString();
                    // FIN APAO 

                    break;
                default:
                    break;
            }//switch
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // va leiendo 
            resultado = 0;
            while (lector_consulta.Read())
            {
                Lista_Temporadas_Id.Add(lector_consulta.GetInt32(0));
                Lista_Temporadas_Anio1_Anio2.Add(lector_consulta.GetInt32(1).ToString() + "-" + lector_consulta.GetInt32(2).ToString());
                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaRangoTemporadas  


        /*Description:
        *   Funcion que retorna el total de jornadas de una determinada temporada
        * Recives:
        *   Por valor:
        *      id_temporada: con el identificador de la temporada de la cual queremos conocer el numero de jornadas
        *      division: con la division o divisiones de la que queremos conocer el total de jornadas
        *   Por referncia:
        *      Lista_Jornadas: con la lista de todas las jornadas (numero de jornada) de esa temporada
        * Returns:
        *   Retorna por valor el total de jornadas de la temporada
        */
        public static int ConsultaNumJornadasTemporada(int id_temporada, List<int> Lista_Jornadas, tipo_division division)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql="";
            int resultado;

            
            // selecciona todos las jornadas de la temporada y division indicadas
            switch (division){
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT DISTINCT N_Jornada FROM Partidos WHERE Division=1 AND Id_Temporada=" + id_temporada.ToString();
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT DISTINCT N_Jornada FROM Partidos WHERE Division=2 AND Id_Temporada=" + id_temporada.ToString();
                    break;
                case tipo_division.PrimeraSegunda:
                    // reotrna todas las jornadas, tanto de primera como de segunda
                    // ATENCION: tener en cuenta que una division puede tener mas jornadas que otra
                    cadena_comando_sql = "SELECT DISTINCT N_Jornada, Division FROM Partidos WHERE Id_Temporada=" + id_temporada.ToString();
                    break;
                default:
                    break;
            }//switch            
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            resultado = 0;

            // va leiendo 
            while (lector_consulta.Read())
            {
                Lista_Jornadas.Add(lector_consulta.GetInt32(0));
                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();
            return resultado;

        }//ConsultaNumJornadasTemporada  


        /*Description:
        *   Funcion que retorna los partidos jugados en una determinada jornada , temporada y division/es con sus resultados
        * Recives:
        *   Por valor:
        *      id_temporada: con el identificador de la temporada de la cual queremos conocer los partidos
        *      n_jornada: con el numero de jornada de la temporada de la qual queremos conocer los partidos
        *      division: con la division o divisiones de la que queremos conocer las jornadas
        *    Por referncia:
        *       Lista_Equipo1: con la lista de todas las jornadas (numero de jornada) de esa temporada
        *       Lista_Equipo2: con la lista de todas las jornadas (numero de jornada) de esa temporada
        *       Lista_Goles_Equipo1: con la lista de goles del Equipo1
        *       Lista_Goles_Equipo2: con la lista de goles del Equipo2
        * Returns:
        *       Retorna por valor el total de partidos de la jornada
        */
        public static int ConsultaPartidosJornada(int id_temporada, int n_jornada, List<string> Lista_Equipo1, List<string> Lista_Equipo2, List<int> Lista_Goles_Equipo1, List<int> Lista_Goles_Equipo2, tipo_division division)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql="";
            int resultado;

            // selecciona todos los partidos de la jornada, temporada y division/es indicadas
            switch (division){
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT e1.Equipo, p.Res_Eq_Local, e2.Equipo, p.Res_Eq_Visitante FROM Equipos e1, Equipos e2 ,Partidos p WHERE e1.Id=p.Id_Eq_Local AND e2.Id=p.Id_Eq_Visitante AND p.Id_Temporada=" + id_temporada.ToString() + " AND p.Division=1 AND p.N_Jornada=" + n_jornada.ToString();
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT e1.Equipo, p.Res_Eq_Local, e2.Equipo, p.Res_Eq_Visitante FROM Equipos e1, Equipos e2 ,Partidos p WHERE e1.Id=p.Id_Eq_Local AND e2.Id=p.Id_Eq_Visitante AND p.Id_Temporada=" + id_temporada.ToString() + " AND p.Division=2 AND p.N_Jornada=" + n_jornada.ToString();
                    break;
                case tipo_division.PrimeraSegunda:
                    cadena_comando_sql = "SELECT e1.Equipo, p.Res_Eq_Local, e2.Equipo, p.Res_Eq_Visitante FROM Equipos e1, Equipos e2 ,Partidos p WHERE e1.Id=p.Id_Eq_Local AND e2.Id=p.Id_Eq_Visitante AND p.Id_Temporada=" + id_temporada.ToString() + " AND (p.Division=1 OR p.Division=2) AND p.N_Jornada=" + n_jornada.ToString();
                    break;
                default:
                    break;
            }//switch
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // va leiendo 
            resultado = 0;
            while (lector_consulta.Read())
            {
                Lista_Equipo1.Add(lector_consulta.GetString(0));
                Lista_Goles_Equipo1.Add(lector_consulta.GetInt32(1));

                Lista_Equipo2.Add(lector_consulta.GetString(2));
                Lista_Goles_Equipo2.Add(lector_consulta.GetInt32(3));
                
                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaPartidosJornada  



        /*Description:
        *   Funcion que retorna el resultado del partido jugado por el equipo en la jornada y temporada indicadas
        * Recives:
        *   Por valor:
        *      id_temporada: con el identificador de la temporada de la cual queremos conocer los partidos
        *      n_jornada: con el numero de jornada de la temporada de la qual queremos conocer los partidos
        *      id_equipo: con el id del equipo del cual queremos conocer el resultado
        *      division: con la division o divisiones de la que queremos conocer las jornadas
        *    Por referncia:
        *       Id_Eq_Local: con la lista de todas las jornadas (numero de jornada) de esa temporada
        *       Id_Eq_Visitante: Lista_Equipo2: con la lista de todas las jornadas (numero de jornada) de esa temporada
        *       Res_Eq_Local: con el resultado del Equipo Local
        *       Res_Eq_Visitante: con el resultado del Equipo Visitante
        * Returns:
        *       Retorna por valor el total de partidos de la jornada
        */
        public static int ConsultaPartidoEquipoJornada(int id_temporada, int n_jornada, int id_equipo, tipo_division division, ref int Id_Eq_Local, ref int Id_Eq_Visitante, ref int Res_Eq_Local, ref int Res_Eq_Visitante)
        {

            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql = "";
            int resultado;

            // selecciona todos los partidos de la jornada, temporada y division/es indicadas
            switch (division)
            {
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT p.Res_Eq_Local, p.Res_Eq_Visitante , p.Id_Eq_Local, p.Id_Eq_Visitante FROM Partidos p WHERE p.Division=1 AND p.Id_Temporada=" + id_temporada.ToString() + " AND p.N_Jornada=" + n_jornada.ToString() + " AND ( p.Id_Eq_Local=" + id_equipo.ToString() + " OR p.Id_Eq_Visitante=" + id_equipo.ToString() + ")";
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT p.Res_Eq_Local, p.Res_Eq_Visitante , p.Id_Eq_Local, p.Id_Eq_Visitante FROM Partidos p WHERE p.Division=2 AND p.Id_Temporada=" + id_temporada.ToString() + " AND p.N_Jornada=" + n_jornada.ToString() + " AND ( p.Id_Eq_Local=" + id_equipo.ToString() + " OR p.Id_Eq_Visitante=" + id_equipo.ToString() + ")";
                    break;
                case tipo_division.PrimeraSegunda:
                    cadena_comando_sql = "SELECT p.Res_Eq_Local, p.Res_Eq_Visitante , p.Id_Eq_Local, p.Id_Eq_Visitante FROM Partidos p WHERE p.Id_Temporada=" + id_temporada.ToString() + " AND p.N_Jornada=" + n_jornada.ToString() + " AND ( p.Id_Eq_Local=" + id_equipo.ToString() + " OR p.Id_Eq_Visitante=" + id_equipo.ToString() + ")";
                    break;
                default:
                    break;
            }//switch
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // leemos los valores consultados
            resultado = 0;
            if (lector_consulta.Read())
            {
                Res_Eq_Local = lector_consulta.GetInt32(0);
                Res_Eq_Visitante = lector_consulta.GetInt32(1);
                Id_Eq_Local = lector_consulta.GetInt32(2);
                Id_Eq_Visitante = lector_consulta.GetInt32(3);
                resultado = resultado + 1;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;


        }//ConsultaPartidoEquipoJornada 


        /*Description:
        *   Funcion que retorna los partidos jugados por el par de equipos indicados dentro del rango de temporadas especificado
        * Recives:
        *   Por valor:
        *      id_eq_local: con el id en la BBDD del equipo local
        *      id_eq_visitante: con el id en la BBDDdel equipo visitante
        *      id_temp_origen: con el id de la temporada inicial del rango
        *      id_temp_final: con el id de la temporada final del rango
        *      tipo_division division: con la division de la queremos obtener los partidos
        * Returns:
        *   Por referencia: los arrays con todos los valores obtenidos tras la consulta a la BBDD
        *      Lista_temporada: con la temporada de cada uno de los partidos retornados
        *      Lista_fecha: con la fecha de cada uno de los partidos retornados
        *      Lista_jornada: con el numero de jornada dentro de la temporda, de cada un de los partidos jugados
        *      Lista_ids_eq_local: con el id del equipo local en el partido ( puede ser o id_eq_local o id_eq_visitante )
        *      Lista_ids_eq_visitante: con el id del equipo visitante en el partido ( puede ser o id_eq_local o id_eq_visitante )
        *      Lista_goles_eq_local: con el numero de goles del equipo que es local el partido ( el equipo puede ser o id_eq_local o id_eq_visitante )
        *      Lista_goles_eq_visitante: con el numero de goles del equipo que es visitante en el partido ( el equipo puede ser o id_eq_local o id_eq_visitante )
        *      Lista_division_encuentro: con la division a la que corresponde cada encuentro
        *   Por valor:
        *      el numero de partidos obtenidos
        */
        public static int ConsultaPartidosEquiposRangoTemporadas(int id_temporada_orig, int id_temporada_fin, int id_eq_local, int id_eq_visitante, tipo_division division, List<string> Lista_temporada, List<string> Lista_fecha, List<int> Lista_jornada, List<int> Lista_ids_eq_local, List<int> Lista_ids_eq_visitante, List<int> Lista_goles_eq_local, List<int> Lista_goles_eq_visitante, List<int> Lista_division_encuentro)
        {
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql = "";
            int resultado;

            int int_aux1;
            int int_aux2;
            string string_aux;

            // si nos han entrado las temporadas al revs ( es decir primero la de fin y luego la de origen ), l
            // las ordenamos. Podemos hacerlo pq los ids de las temporadas estan ordenados cornologicamente en 
            // la BBDD, siendo los IDs mayores los de temporadas mas antiguas y los IDs menores los de temporadas
            // mas recientes
            if (id_temporada_orig < id_temporada_fin)
            {
                int_aux1 = id_temporada_orig;
                id_temporada_orig = id_temporada_fin;
                id_temporada_fin = int_aux1;
            }//    if                 

            // preparamos una cadena SQL u otra dependiendo de la consulta a realizar sobre la BBDD
            switch (division)
            {
                case tipo_division.Primera:
                    cadena_comando_sql = "SELECT t.Anio1, t.Anio2, p.Fecha, p.N_Jornada, p.Id_Eq_Local, p.Id_Eq_Visitante, p.Res_Eq_Local, p.Res_Eq_Visitante FROM Temporadas t, Partidos p WHERE t.Id=p.Id_Temporada AND p.Id_Temporada <=" + id_temporada_orig.ToString() + " AND p.Id_Temporada >=" + id_temporada_fin.ToString() + " AND p.Division=1 AND  ( ( p.Id_Eq_Local = " + id_eq_local.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_visitante.ToString() + " ) OR ( p.Id_Eq_Local = " + id_eq_visitante.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_local.ToString() + " ) )";
                    break;
                case tipo_division.Segunda:
                    cadena_comando_sql = "SELECT t.Anio1, t.Anio2, p.Fecha, p.N_Jornada, p.Id_Eq_Local, p.Id_Eq_Visitante, p.Res_Eq_Local, p.Res_Eq_Visitante FROM Temporadas t, Partidos p WHERE t.Id=p.Id_Temporada AND p.Id_Temporada <=" + id_temporada_orig.ToString() + " AND p.Id_Temporada >=" + id_temporada_fin.ToString() + " AND p.Division=2 AND  ( ( p.Id_Eq_Local = " + id_eq_local.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_visitante.ToString() + " ) OR ( p.Id_Eq_Local = " + id_eq_visitante.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_local.ToString() + " ) )";
                    break;
                case tipo_division.PrimeraSegunda:
                    cadena_comando_sql = "SELECT t.Anio1, t.Anio2, p.Fecha, p.N_Jornada, p.Id_Eq_Local, p.Id_Eq_Visitante, p.Res_Eq_Local, p.Res_Eq_Visitante , p.Division FROM Temporadas t, Partidos p WHERE t.Id=p.Id_Temporada AND p.Id_Temporada <=" + id_temporada_orig.ToString() + " AND p.Id_Temporada >=" + id_temporada_fin.ToString() + " AND ( ( p.Id_Eq_Local = " + id_eq_local.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_visitante.ToString() + " ) OR ( p.Id_Eq_Local = " + id_eq_visitante.ToString() + " AND p.Id_Eq_Visitante =" + id_eq_local.ToString() + " ) )";
                    break;
                default:
                    break;
            }//switch
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // leemos los valores consultados
            resultado = 0;
            string formato = "yyyy/MM/dd"; // ao/mes/dia
            while (lector_consulta.Read())
            {
                int_aux1 = lector_consulta.GetInt32(0);// anio1
                int_aux2 = lector_consulta.GetInt32(1);// anio2
                string_aux = int_aux1.ToString() + "/" + int_aux2.ToString();// aadimos la temporada a la lista en la que guardamos la temporada a la que pertenece el partido procesado
                Lista_temporada.Add(string_aux);

                string_aux = lector_consulta.GetDateTime(2).ToString(formato);//ToShortDateString();// fecha del partido procesado
                
                Lista_fecha.Add(string_aux);// aadimos la temporada a la lista en la que guardamos la fecah de cada partido

                Lista_jornada.Add(lector_consulta.GetInt32(3)); // numero de jornada del partido procesado, se aade a la lista en que guardamos el numero de jornada de cada encuentro

                Lista_ids_eq_local.Add(lector_consulta.GetInt32(4)); // Id del equipo que es local en el partido procesado( puede ser tanto el recibido en el parametro id_local, como id_visitante )
                Lista_ids_eq_visitante.Add(lector_consulta.GetInt32(5)); // Id del equipo que es visitante en el partido procesado ( puede ser tanto el recibido en el parametro id_local, como id_visitante )

                Lista_goles_eq_local.Add(lector_consulta.GetInt32(6)); // numero de goles del equipo local en el partido procesado
                Lista_goles_eq_visitante.Add(lector_consulta.GetInt32(7)); // numero de goles del equipo visitante en el partido procesado

                // tambien guardamos la division de cada uno de los encuentros retornados
                switch (division){
                    case tipo_division.Primera:
                        // si en la consulta hemos especificado solo los de 1a entonces ponemos directamente '1'
                        Lista_division_encuentro.Add(1);
                        break;
                    case tipo_division.Segunda:
                        // si en la consulta hemos especificado solo los de 2a entonces ponemos directamente '2'
                        Lista_division_encuentro.Add(2);
                        break;
                    case tipo_division.PrimeraSegunda:
                        // si en la consulta hemos indicado tanto los de 1a como los de 2a entonces tenemos que mirar lo que ha retornado la consulta
                        Lista_division_encuentro.Add(lector_consulta.GetInt32(8));
                        break;
                }//switch

                resultado = resultado + 1;
            }//while

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            return resultado;

        }//ConsultaPartidosEquiposRangoTemporadas



        /*Description:
         *   Procedimiento que dado un enfrentamiento entre dos equipos, calcula las probabilidades de cada resutlado considerando el factor campo, 
         *   y retorna ademas otras variables relacionadas con este
         * Recives:
         *   equipo_uno: con el nombre del equipo local
         *   equipo_dos: con el nombre del equipo visitante
         * Returns:
         *   victorias_uno: total de victorias del equipo uno jugando como equipo local
         *   goles_uno:  total de goles marcados por el equipo uno jugando como equipo local
         *   unos: probabilidades que gane el equipo uno teniendo en cuenta que es el local
         *   equis: probabilidades de que emapten
         *   doses: probabilidades que gane el equipo dos teniendo en cuenta que es el visitante
         *   goles_dos: total de goles marcados por el equipo dos jugando como equipo visitante
         *   victorias_dos: total de victorias del equipo dos teniendo en cuenta que es el visitante
         *   empates: total de empates entre ambos equipos siendo equipo uno local y equipo 2 visitante
         * Por valor:
         *   true: si ha localizado la informacion de los equipos
         *   false: si no ha localizado la informacion de los equipos
         */
        public static bool ProbabilidadConFactorCampo(string equipo_uno, string equipo_dos, int id_temporada_orig, int id_temporada_fin, ref int victorias_uno, ref int goles_uno, ref  float unos, ref  float equis, ref  float doses, ref  int goles_dos, ref  int victorias_dos, ref  int empates, ref  int total_partidos)
        {
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql;
            int id_equipo_uno;
            int id_equipo_dos;
            int resultado_eq_uno;
            int resultado_eq_dos;
            int partidos_analizados;
            int partidos_ganados_uno;
            int partidos_empatados;
            int partidos_ganados_dos;
            int total_goles_eq_uno;
            int total_goles_eq_dos;
            int int_aux;


            // si nos han entrado las temporadas al revs ( es decir primero la de fin y luego la de origen ), l
            // las ordenamos. Podemos hacerlo pq los ids de las temporadas estan ordenados cornologicamente en 
            // la BBDD, siendo los IDs mayores los de temporadas mas antiguas y los IDs menores los de temporadas
            // mas recientes
            if (id_temporada_orig < id_temporada_fin){
                int_aux = id_temporada_orig;
                id_temporada_orig = id_temporada_fin;
                id_temporada_fin = int_aux;
            }//if

            // primero obtenemos el ID de cada uno de los dos equipos
            // selecciona el Id del equipo con nombre equipo_uno
            cadena_comando_sql = "SELECT Id FROM Equipos WHERE Equipo='" + equipo_uno+"'";
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            if (lector_consulta.Read()){
                id_equipo_uno = lector_consulta.GetInt32(0);
            }else{
                MessageBox.Show("ERROR: No se ha podido obtener el ID del equipo uno");
                return false;
            }//if            

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            // selecciona el Id del equipo con nombre equipo_dos
            cadena_comando_sql = "SELECT Id FROM Equipos WHERE Equipo='" + equipo_dos + "'";
            comando_sql.Dispose();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            if (lector_consulta.Read()){
                id_equipo_dos = lector_consulta.GetInt32(0);
            }else{
                MessageBox.Show("ERROR: No se ha podido obtener el ID del equipo dos");
                return false;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            // seleccionamos todos los partidos en que el equipo local es equipo_uno y el equipo visitante el equipo_dos
            cadena_comando_sql = "SELECT p.Res_Eq_Local,p.Res_Eq_Visitante FROM Partidos p, Temporadas t WHERE p.Id_temporada=t.Id AND p.Id_Eq_Local=" + id_equipo_uno.ToString() + " AND p.Id_Eq_Visitante=" + id_equipo_dos.ToString() + "AND t.Id>=" + id_temporada_fin.ToString() + " AND t.Id<=" + id_temporada_orig.ToString();
            comando_sql.Dispose();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // se interpretan y calculan los valores necesarios a partir de la informacion de jornada
            partidos_ganados_uno = 0;
            partidos_ganados_dos = 0;
            partidos_empatados = 0;
            partidos_analizados = 0;
            total_goles_eq_uno = 0;
            total_goles_eq_dos = 0;
            while (lector_consulta.Read()){
                resultado_eq_uno = lector_consulta.GetInt32(0); // se lee los goles hechos en el partido por el equipo uno
                resultado_eq_dos = lector_consulta.GetInt32(1); // se lee los goles hechos en el partido por el equipo dos
                total_goles_eq_uno = total_goles_eq_uno + resultado_eq_uno; // se acumula el numero de goles de cada equipo
                total_goles_eq_dos = total_goles_eq_dos + resultado_eq_dos; // se acumula el numero de goles de cada equipo
                
                // en base al resultado se interpreta la victoria o empate...
                if (resultado_eq_uno>resultado_eq_dos){
                    partidos_ganados_uno++;
                }else if (resultado_eq_uno<resultado_eq_dos){
                    partidos_ganados_dos++;
                }else{
                    partidos_empatados++;
                }//if               
                partidos_analizados++;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            // se realizan algunos pequelos calculos finales
            if (partidos_analizados>0){
                victorias_uno = partidos_ganados_uno;
                goles_uno = total_goles_eq_uno;
                unos = ((float)partidos_ganados_uno / (float)partidos_analizados) * 100;
                equis = ((float)partidos_empatados / (float)partidos_analizados) * 100;
                doses = ((float)partidos_ganados_dos / (float)partidos_analizados) * 100;
                goles_dos= total_goles_eq_dos;
                victorias_dos = partidos_ganados_dos;
                empates = partidos_empatados;
                total_partidos = partidos_analizados;
                return true;
            }else{
                return false;
            }

        }//ProbabilidadConFactorCampo


        /*Description:
        *   Procedimiento que dado un enfrentamiento entre dos equipos, calcula las probabilidades de cada resutlado sin considerar el factor campo, 
        *   y retorna ademas otras variables relacionadas con este
        * Recives:
        *   equipo_uno: con el nombre del equipo local
        *   equipo_dos: con el nombre del equipo visitante
        * Returns:
        *   victorias_uno: total de victorias del equipo uno jugando como equipo local
        *   goles_uno:  total de goles marcados por el equipo uno jugando como equipo local
        *   unos: probabilidades que gane el equipo uno teniendo en cuenta que es el local
        *   equis: probabilidades de que emapten
        *   doses: probabilidades que gane el equipo dos teniendo en cuenta que es el visitante
        *   goles_dos: total de goles marcados por el equipo dos jugando como equipo visitante
        *   victorias_dos: total de victorias del equipo dos teniendo en cuenta que es el visitante
        *   empates: total de empates entre ambos equipos siendo equipo uno local y equipo 2 visitante
        * Por valor:
        *   true: si ha localizado la informacion de los equipos
        *   false: si no ha localizado la informacion de los equipos
        */
        public static bool ProbabilidadSinFactorCampo(string equipo_uno, string equipo_dos, int id_temporada_orig, int id_temporada_fin, ref int victorias_uno, ref int goles_uno, ref  float unos, ref  float equis, ref  float doses, ref  int goles_dos, ref  int victorias_dos, ref  int empates, ref  int total_partidos)
        {
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql;
            int id_equipo_uno;
            int id_equipo_dos;
            int resultado_eq_uno;
            int resultado_eq_dos;
            int partidos_analizados;
            int partidos_ganados_uno;
            int partidos_empatados;
            int partidos_ganados_dos;
            int total_goles_eq_uno;
            int total_goles_eq_dos;
            int int_aux;

            // si nos han entrado las temporadas al revs ( es decir primero la de fin y luego la de origen ), l
            // las ordenamos. Podemos hacerlo pq los ids de las temporadas estan ordenados cornologicamente en 
            // la BBDD, siendo los IDs mayores los de temporadas mas antiguas y los IDs menores los de temporadas
            // mas recientes
            if (id_temporada_orig < id_temporada_fin){
                int_aux = id_temporada_orig;
                id_temporada_orig = id_temporada_fin;
                id_temporada_fin = int_aux;
            }//if

            // primero obtenemos el ID de cada uno de los dos equipos
            // selecciona el Id del equipo con nombre equipo_uno
            cadena_comando_sql = "SELECT Id FROM Equipos WHERE Equipo='" + equipo_uno + "'";
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            if (lector_consulta.Read()){

                id_equipo_uno = lector_consulta.GetInt32(0);

            }else{

                MessageBox.Show("ERROR: No se ha podido obtener el ID del equipo uno");
                return false;

            }//if            

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            // selecciona el Id del equipo con nombre equipo_dos
            cadena_comando_sql = "SELECT Id FROM Equipos WHERE Equipo='" + equipo_dos + "'";
            comando_sql.Dispose();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();
            if (lector_consulta.Read())
            {
                id_equipo_dos = lector_consulta.GetInt32(0);
            }
            else
            {
                MessageBox.Show("ERROR: No se ha podido obtener el ID del equipo dos");
                return false;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();
            
            // seleccionamos todos los partidos en que el equipo local es equipo_uno y el equipo visitante el equipo_dos
            cadena_comando_sql = "SELECT p.Res_Eq_Local,p.Res_Eq_Visitante FROM Partidos p, Temporadas t WHERE p.Id_temporada=t.Id AND p.Id_Eq_Local=" + id_equipo_uno.ToString() + " AND p.Id_Eq_Visitante=" + id_equipo_dos.ToString() + "AND t.Id>=" + id_temporada_fin.ToString() + " AND t.Id<=" + id_temporada_orig.ToString(); ;
            comando_sql.Dispose();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // se interpretan y calculan los valores necesarios a partir de la informacion de jornada
            partidos_ganados_uno = 0;
            partidos_ganados_dos = 0;
            partidos_empatados = 0;
            partidos_analizados = 0;
            total_goles_eq_uno = 0;
            total_goles_eq_dos = 0;
            while (lector_consulta.Read())
            {
                resultado_eq_uno = lector_consulta.GetInt32(0); // se lee los goles hechos en el partido por el equipo uno
                resultado_eq_dos = lector_consulta.GetInt32(1); // se lee los goles hechos en el partido por el equipo dos
                total_goles_eq_uno = total_goles_eq_uno + resultado_eq_uno; // se acumula el numero de goles de cada equipo
                total_goles_eq_dos = total_goles_eq_dos + resultado_eq_dos; // se acumula el numero de goles de cada equipo

                // en base al resultado se interpreta la victoria o empate...
                if (resultado_eq_uno > resultado_eq_dos)
                {
                    partidos_ganados_uno++;
                }
                else if (resultado_eq_uno < resultado_eq_dos)
                {
                    partidos_ganados_dos++;
                }
                else
                {
                    partidos_empatados++;
                }//if               
                partidos_analizados++;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();
                        
            // ahora realizamos la seleccion CONTRARIA, es decir todos los partidos en que el equipo local es equipo_dos y el equipo visitante el equipo_uno
            cadena_comando_sql = "SELECT p.Res_Eq_Local,p.Res_Eq_Visitante FROM Partidos p,Temporadas t WHERE p.Id_temporada=t.Id AND p.Id_Eq_Local=" + id_equipo_dos.ToString() + " AND p.Id_Eq_Visitante=" + id_equipo_uno.ToString() + "AND t.Id>=" + id_temporada_fin.ToString() + " AND t.Id<=" + id_temporada_orig.ToString(); ;
            comando_sql.Dispose();
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            // se interpretan y calculan los valores necesarios a partir de la informacion de jornada
            while (lector_consulta.Read())
            {
                resultado_eq_dos = lector_consulta.GetInt32(0); // se lee los goles hechos en el partido por el equipo uno
                resultado_eq_uno = lector_consulta.GetInt32(1); // se lee los goles hechos en el partido por el equipo dos
                total_goles_eq_dos = total_goles_eq_dos+ resultado_eq_dos; // se acumula el numero de goles de cada equipo
                total_goles_eq_uno = total_goles_eq_uno + resultado_eq_uno; // se acumula el numero de goles de cada equipo

                // en base al resultado se interpreta la victoria o empate...
                if (resultado_eq_uno > resultado_eq_dos)
                {
                    partidos_ganados_uno++;
                }
                else if (resultado_eq_uno < resultado_eq_dos)
                {
                    partidos_ganados_dos++;
                }
                else
                {
                    partidos_empatados++;
                }//if               
                partidos_analizados++;
            }//if

            // cerramos el objeto utilizado para la lectura de la BBDD
            lector_consulta.Close();

            // se realizan algunos pequeos calculos finales
            if (partidos_analizados > 0)
            {
                victorias_uno = partidos_ganados_uno;
                goles_uno = total_goles_eq_uno;
                unos = ((float)partidos_ganados_uno / (float)partidos_analizados) * 100;
                equis = ((float)partidos_empatados / (float)partidos_analizados) * 100;
                doses = ((float)partidos_ganados_dos / (float)partidos_analizados) * 100;
                goles_dos = total_goles_eq_dos;
                victorias_dos = partidos_ganados_dos;
                empates = partidos_empatados;
                total_partidos = partidos_analizados;
                return true;
            }
            else
            {
                return false;
            }

        }//ProbabilidadSinFactorCampo


        /*Description:
        *   Funcion que actualiza en la BBDD las diferentes variables referentes a los resultados de un equipo. Estas
        * variables son:
        *   Vic_Casa_1a , Vic_F_Casa_1a , Derr_Casa_1a , Derr_F_Casa_1a , Emp_Casa_1a , Emp_F_Casa_1a 
        *   Gol_Marc_Casa_1a , Gol_Marc_F_Casa_1a , Vic_Casa_2a , Vic_F_Casa_2a , Derr_Casa_2a ,
        *   Derr_F_Casa_2a , Emp_Casa_2a , Emp_F_Casa_2a, Gol_Marc_Casa_1a , Gol_Marc_F_Casa_1a
        * Recives:
        *   id_temporada_orig: con el identificador de la temporada a partir de la cual comenzamos a calcular las variables ( la mas antigua del rango)
        *   id_temporada_fin: con el identificador de la temporada hasta la que calculamos las variables de los equipos ( la mas nueva del rango)
        * Returns:
        * Por valor:
        *   true si todo ha ido bien
        *   false si se ha producido algun tipo de error
        */
        public static bool ActualizaVariablesEquipos(int id_temporada_orig,int id_temporada_fin)
        {
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql;
            // para recorrer todos los equipos
            int total_equipos;
            int int_aux;
            // para guardar temporalmente los valores leidos de la BBDD
            int res_eq_local;
            int res_eq_visitante;         
            // para almacenar las variables relativas a 1a division
            int vic_casa_1a;
            int vic_f_casa_1a;
            int derr_casa_1a;
            int derr_f_casa_1a;
            int emp_casa_1a;
            int emp_f_casa_1a;
            int gol_marc_casa_1a;
            int gol_marc_f_casa_1a;
            int gol_encaj_casa_1a;
            int gol_encaj_f_casa_1a;           
            // para almacenar las variables relativas a 2a division
            int vic_casa_2a;
            int vic_f_casa_2a;
            int derr_casa_2a;
            int derr_f_casa_2a;
            int emp_casa_2a;
            int emp_f_casa_2a;
            int gol_marc_casa_2a;
            int gol_marc_f_casa_2a;
            int gol_encaj_casa_2a;
            int gol_encaj_f_casa_2a;
            // listas utilizadas para recibir de ConsultaEquipos la lista de todos los equipos de la BBDD
            List<int> Lista_Equipos_Id = new List<int>();
            List<string> Lista_Equipos_Equipo = new List<string>();

            // si nos han entrado las temporadas al revs ( es decir primero la de fin y luego la de origen ), l
            // las ordenamos. Podemos hacerlo pq los ids de las temporadas estan ordenados cornologicamente en 
            // la BBDD, siendo los IDs mayores los de temporadas mas antiguas y los IDs menores los de temporadas
            // mas recientes
            if (id_temporada_orig < id_temporada_fin){
                int_aux = id_temporada_orig;
                id_temporada_orig=id_temporada_fin;
                id_temporada_fin = int_aux;
            }//if

            // obtenemos la lista con todos los equipos presentes en la BBDD
            total_equipos=ConsultaEquipos(Lista_Equipos_Id,Lista_Equipos_Equipo);
            if (total_equipos <= 0){

                MessageBox.Show("ERROR: No se ha podido obtener la lista de equipos");
                return false;

            }else{

                // se procesa cada uno de lo equipos de la BBDD que hemos recibido en la lista de equipos
                int_aux = 0;
                while (int_aux<total_equipos){
       
                    // 1a DIVISION y EQUIPO JUEGA COMO LOCAL

                    //seleccionamos todos los partidos de 1a division en que el equipo procesado juega como local y esta en el rango de temporadas
                    cadena_comando_sql = "SELECT * FROM Partidos WHERE Id_Eq_Local=" + Lista_Equipos_Id[int_aux] + " AND Id_Temporada<=" + id_temporada_orig.ToString() + " AND Id_Temporada>="+ id_temporada_fin.ToString() +" AND Division=1";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();
                    
                    // se interpretan y calculan los valores necesarios a partir de la informacion del partido
                    vic_casa_1a = 0;
                    derr_casa_1a = 0;
                    emp_casa_1a = 0;
                    gol_marc_casa_1a = 0;
                    gol_encaj_casa_1a = 0;
                    while (lector_consulta.Read()){            

                        res_eq_local = lector_consulta.GetInt32(4);
                        res_eq_visitante = lector_consulta.GetInt32(6);

                        // actualizamos las variables que tocan en funcion del resultado
                        if (res_eq_local>res_eq_visitante){
                            vic_casa_1a++;
                        }else if (res_eq_local<res_eq_visitante){
                            derr_casa_1a++;
                        }else{
                            emp_casa_1a++;
                        }//if
                        gol_marc_casa_1a = gol_marc_casa_1a + res_eq_local;
                        gol_encaj_casa_1a = gol_encaj_casa_1a + res_eq_visitante;
    
                    }//while
                    
                    lector_consulta.Close();
                    comando_sql.Dispose();

                    // 1a DIVISION y EQUIPO JUEGA COMO VISITANTE

                    //seleccionamos todos los partidos de 1a division en que el equipo procesado juega como visitante
                    cadena_comando_sql = "SELECT * FROM Partidos WHERE Id_Eq_Visitante=" + Lista_Equipos_Id[int_aux] + " AND Id_Temporada<=" + id_temporada_orig.ToString() + " AND Id_Temporada>=" + id_temporada_fin.ToString() + " AND Division=1";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();

                    // se interpretan y calculan los valores necesarios a partir de la informacion del partido
                    vic_f_casa_1a = 0;
                    derr_f_casa_1a = 0;
                    emp_f_casa_1a = 0;
                    gol_marc_f_casa_1a = 0;
                    gol_encaj_f_casa_1a = 0;
                    while (lector_consulta.Read()){

                        res_eq_local = lector_consulta.GetInt32(4);
                        res_eq_visitante = lector_consulta.GetInt32(6);

                        // actualizamos las variables que tocan en funcion del resultado
                        if (res_eq_local > res_eq_visitante){
                            derr_f_casa_1a++;
                        }else if (res_eq_local < res_eq_visitante){
                            vic_f_casa_1a++;
                        }else{
                            emp_f_casa_1a++;
                        }//if
                        gol_marc_f_casa_1a = gol_marc_f_casa_1a + res_eq_visitante;
                        gol_encaj_f_casa_1a = gol_encaj_f_casa_1a + res_eq_local;

                    }//while

                    lector_consulta.Close();
                    comando_sql.Dispose();

                    // 2a DIVISION y EQUIPO JUEGA COMO LOCAL

                    //seleccionamos todos los partidos de 1a division en que el equipo procesado juega como local
                    cadena_comando_sql = "SELECT * FROM Partidos WHERE Id_Eq_Local=" + Lista_Equipos_Id[int_aux] + " AND Id_Temporada<=" + id_temporada_orig.ToString() + " AND Id_Temporada>=" + id_temporada_fin.ToString() + " AND Division=2";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();

                    // se interpretan y calculan los valores necesarios a partir de la informacion del partido
                    vic_casa_2a = 0;
                    derr_casa_2a = 0;
                    emp_casa_2a = 0;
                    gol_marc_casa_2a = 0;
                    gol_encaj_casa_2a = 0;
                    while (lector_consulta.Read()){

                        res_eq_local = lector_consulta.GetInt32(4);
                        res_eq_visitante = lector_consulta.GetInt32(6);

                        // actualizamos las variables que tocan en funcion del resultado
                        if (res_eq_local > res_eq_visitante){
                            vic_casa_2a++;
                        }else if (res_eq_local < res_eq_visitante){
                            derr_casa_2a++;
                        }else{
                            emp_casa_2a++;
                        }//if
                        gol_marc_casa_2a = gol_marc_casa_2a + res_eq_local;
                        gol_encaj_casa_2a = gol_encaj_casa_2a + res_eq_visitante;

                    }//while

                    lector_consulta.Close();
                    comando_sql.Dispose();

                    // 2a DIVISION y EQUIPO JUEGA COMO VISITANTE

                    //seleccionamos todos los partidos de 1a division en que el equipo procesado juega como visitante
                    cadena_comando_sql = "SELECT * FROM Partidos WHERE Id_Eq_Visitante=" + Lista_Equipos_Id[int_aux] + " AND Id_Temporada<=" + id_temporada_orig.ToString() + " AND Id_Temporada>=" + id_temporada_fin.ToString() + " AND Division=2";
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    lector_consulta = comando_sql.ExecuteReader();

                    // se interpretan y calculan los valores necesarios a partir de la informacion del partido
                    vic_f_casa_2a = 0;
                    derr_f_casa_2a = 0;
                    emp_f_casa_2a = 0;
                    gol_marc_f_casa_2a = 0;
                    gol_encaj_f_casa_2a = 0;
                    while (lector_consulta.Read()){

                        res_eq_local = lector_consulta.GetInt32(4);
                        res_eq_visitante = lector_consulta.GetInt32(6);

                        // actualizamos las variables que tocan en funcion del resultado
                        if (res_eq_local > res_eq_visitante){
                            derr_f_casa_2a++;
                        }else if (res_eq_local < res_eq_visitante){
                            vic_f_casa_2a++;
                        }else{
                            emp_f_casa_2a++;
                        }//if
                        gol_marc_f_casa_2a = gol_marc_f_casa_2a + res_eq_visitante;
                        gol_encaj_f_casa_2a = gol_encaj_f_casa_2a + res_eq_local;

                    }//while

                    lector_consulta.Close();
                    comando_sql.Dispose();
                    
                    //actualizamos la entrada asociada al equipo
                    cadena_comando_sql = "UPDATE Equipos SET Vic_Casa_1a=" + vic_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Vic_F_Casa_1a=" + vic_f_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Derr_Casa_1a=" + derr_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Derr_F_Casa_1a=" + derr_f_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Emp_Casa_1a=" + emp_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Emp_F_Casa_1a=" + emp_f_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Marc_Casa_1a=" + gol_marc_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Marc_F_Casa_1a=" + gol_marc_f_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Encaj_Casa_1a=" + gol_encaj_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Encaj_F_Casa_1a=" + gol_encaj_f_casa_1a;
                    cadena_comando_sql = cadena_comando_sql + " ,Vic_Casa_2a=" + vic_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Vic_F_Casa_2a=" + vic_f_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Derr_Casa_2a=" + derr_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Derr_F_Casa_2a=" + derr_f_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Emp_Casa_2a=" + emp_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Emp_F_Casa_2a=" + emp_f_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Marc_Casa_2a=" + gol_marc_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Marc_F_Casa_2a=" + gol_marc_f_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Encaj_Casa_2a=" + gol_encaj_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " ,Gol_Encaj_F_Casa_2a=" + gol_encaj_f_casa_2a;
                    cadena_comando_sql = cadena_comando_sql + " WHERE Id="+ Lista_Equipos_Id[int_aux];
                    comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
                    comando_sql.ExecuteNonQuery();
                    comando_sql.Dispose();

                    // procesamos el siguiente equipo de la lista
                    int_aux++;

                }//while

            }//if

            return true;

        }//ActualizaVariablesEquipos



        /*Description:
        *   Funcion que obtiene de la BBDD toda la informacin del equipo solicitado ( del que se le pasa el id_equipo )
        * Recives:
        *   id_equipo:con el identificador del equipo del que queremos conocer todas las variables
        * Returns:
        * Por valor:
        *   true si todo ha ido bien
        *   false si no se ha localizado el equipo indicado se ha producido algun tipo de error
        */
        public static bool ConsultaVariablesEquipo(int id_equipo, ref int vic_casa_1a, ref int vic_f_casa_1a, ref int derr_casa_1a, ref int derr_f_casa_1a, ref int emp_casa_1a, ref int emp_f_casa_1a, ref int gol_marc_casa_1a, ref int gol_marc_f_casa_1a, ref int gol_encaj_casa_1a, ref int gol_encaj_f_casa_1a, ref int vic_casa_2a, ref int vic_f_casa_2a, ref int derr_casa_2a, ref int derr_f_casa_2a, ref int emp_casa_2a, ref int emp_f_casa_2a, ref int gol_marc_casa_2a, ref int gol_marc_f_casa_2a, ref int gol_encaj_casa_2a, ref int gol_encaj_f_casa_2a){
            OleDbCommand comando_sql;
            OleDbDataReader lector_consulta;
            string cadena_comando_sql;
            // para recorrer todos los equipos
            // para almacenar las variables relativas a 1a division


            //seleccionamos toda la informacin asociada al ID del equipo que hemos recibido
            cadena_comando_sql = "SELECT * FROM Equipos WHERE Id=" + id_equipo;
            comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
            lector_consulta = comando_sql.ExecuteReader();

            if (!lector_consulta.Read()){
                
                MessageBox.Show("ERROR: No se ha encontrado ningun equipo con este Id");
                return false;

            }else{
                // variables relativas a 1a division
                vic_casa_1a = lector_consulta.GetInt32(2);
                vic_f_casa_1a = lector_consulta.GetInt32(3);
                derr_casa_1a = lector_consulta.GetInt32(4);
                derr_f_casa_1a = lector_consulta.GetInt32(5);
                emp_casa_1a = lector_consulta.GetInt32(6);
                emp_f_casa_1a = lector_consulta.GetInt32(7);
                gol_marc_casa_1a = lector_consulta.GetInt32(8);
                gol_marc_f_casa_1a = lector_consulta.GetInt32(9);
                gol_encaj_casa_1a = lector_consulta.GetInt32(10);
                gol_encaj_f_casa_1a = lector_consulta.GetInt32(11);
                // variables relativas a 2a division
                vic_casa_2a = lector_consulta.GetInt32(12);
                vic_f_casa_2a = lector_consulta.GetInt32(13);
                derr_casa_2a = lector_consulta.GetInt32(14);
                derr_f_casa_2a = lector_consulta.GetInt32(15);
                emp_casa_2a = lector_consulta.GetInt32(16);
                emp_f_casa_2a = lector_consulta.GetInt32(17);
                gol_marc_casa_2a = lector_consulta.GetInt32(18);
                gol_marc_f_casa_2a = lector_consulta.GetInt32(19);
                gol_encaj_casa_2a = lector_consulta.GetInt32(20);
                gol_encaj_f_casa_2a = lector_consulta.GetInt32(21);
                
                return true;
            
            }//if

      }//ConsultaVariablesEquipo



      /*Description:
      *   Funcion que retorna el identificador del equipo cuyo nombre recibe por valor
      * Recives:
      *   Por valor:
      *      nombre_equipo: con el nombre del equipo del cual queremos obtener el ID
      *    Por referncia:
      * Returns:
      *       Retorna por valor el Id del equipo que cuyo nombre ha recibido
      */
      public static int ConsultaIdEquipo(string nombre_equipo)
      {

          OleDbCommand comando_sql;
          OleDbDataReader lector_consulta;
          string cadena_comando_sql;
          int id_equipo;

          // obtenemos el Id del equipo con nombre nombre_equipo
          cadena_comando_sql = "SELECT Id FROM Equipos WHERE Equipo='" + nombre_equipo + "'";
          comando_sql = new OleDbCommand(cadena_comando_sql, conector_BBDD);
          lector_consulta = comando_sql.ExecuteReader();
          if (lector_consulta.Read())
          {
              id_equipo = lector_consulta.GetInt32(0);
          }
          else
          {
              MessageBox.Show("ERROR: No se ha podido obtener el ID del equipo indicado");
              return -1;
          }//if            

          // cerramos el objeto utilizado para la lectura de la BBDD
          lector_consulta.Close();

          return id_equipo;

      }//ConsultaIdEquipo  



    }

}
